@@ -3,7 +3,9 @@ use crate::{interval::*, simd::*};
 impl Interval {
     /// Rounds `self` to the closest integer toward $+∞$.
     ///
-    /// Tightness: tightest
+    /// | Domain | Range |
+    /// | ------ | ----- |
+    /// | $\R$   | $\Z$  |
     ///
     /// # Examples
     ///
@@ -28,7 +30,9 @@ impl Interval {
 
     /// Rounds `self` to the closest integer toward $-∞$.
     ///
-    /// Tightness: tightest
+    /// | Domain | Range |
+    /// | ------ | ----- |
+    /// | $\R$   | $\Z$  |
     ///
     /// # Examples
     ///
@@ -52,7 +56,9 @@ impl Interval {
 
     /// Rounds `self` to the closest integer, away from zero in case of ties.
     ///
-    /// Tightness: tightest
+    /// | Domain | Range |
+    /// | ------ | ----- |
+    /// | $\R$   | $\Z$  |
     ///
     /// # Examples
     ///
@@ -77,7 +83,9 @@ impl Interval {
 
     /// Rounds `self` to the closest integer, the even number in case of ties.
     ///
-    /// Tightness: tightest
+    /// | Domain | Range |
+    /// | ------ | ----- |
+    /// | $\R$   | $\Z$  |
     ///
     /// # Examples
     ///
@@ -102,11 +110,13 @@ impl Interval {
 
     /// Returns the sign of `self`.
     ///
+    /// | Domain | Range            |
+    /// | ------ | ---------------- |
+    /// | $\R$   | $\set{-1, 0, 1}$ |
+    ///
     /// Note the difference in definition between [`f64::signum`] and this function;
     /// `+0.0_f64.signum()` and `-0.0_f64.signum()` return `+1.0` and `-1.0`, respectively,
-    /// while the sign of zero is just zero,
-    ///
-    /// Tightness: tightest
+    /// while the sign of zero is just zero.
     ///
     /// # Examples
     ///
@@ -137,7 +147,9 @@ impl Interval {
 
     /// Rounds `self` to the closest integer toward zero.
     ///
-    /// Tightness: tightest
+    /// | Domain | Range |
+    /// | ------ | ----- |
+    /// | $\R$   | $\Z$  |
     ///
     /// # Examples
     ///
@@ -167,7 +179,9 @@ macro_rules! impl_dec {
     // In rounding functions, you can effectively check if an endpoint of x
     // is an integer by x.inf == y.inf or x.sup == y.sup.
     ($f:ident, $x:ident, $y:ident, $is_not_com:expr) => {
-        #[doc = concat!("See [`Interval::", stringify!($f), "`].")]
+        #[doc = concat!("The decorated version of [`Interval::", stringify!($f), "`].")]
+        ///
+        /// A NaI is returned if `self` is NaI.
         pub fn $f(self) -> Self {
             if self.is_nai() {
                 return self;
@@ -195,7 +209,7 @@ impl DecInterval {
     impl_dec!(ceil, x, y, x.sup_raw() == y.sup_raw()); // No need to check inf.
     impl_dec!(floor, x, y, x.inf_raw() == y.inf_raw()); // No need to check sup.
 
-    // Discontinuities: {x + 0.5 | x ∈ ℤ}.
+    // Discontinuities: {x + 0.5 ∣ x ∈ ℤ}.
     impl_dec!(round, x, y, {
         let abs_a = x.inf_raw().abs();
         let abs_b = x.sup_raw().abs();
